@@ -1,6 +1,6 @@
 package Elastic::Model::Role::Model;
 {
-  $Elastic::Model::Role::Model::VERSION = '0.05';
+  $Elastic::Model::Role::Model::VERSION = '0.06';
 }
 
 use Moose::Role;
@@ -419,7 +419,8 @@ sub _update_unique_keys {
 
     my ( %old, %new );
     for my $key ( keys %$uniques ) {
-        my $new = $doc->$key;
+        my $unique_key = $uniques->{$key};
+        my $new        = $doc->$key;
 
         if ($from_store) {
             my $old
@@ -428,10 +429,10 @@ sub _update_unique_keys {
                 : $doc->$key;
             no warnings 'uninitialized';
             next if $from_store and $old eq $new;
-            $old{$key} = $old if defined $old and length $old;
+            $old{$unique_key} = $old if defined $old and length $old;
         }
 
-        $new{$key} = $new if defined $new and length $new;
+        $new{$unique_key} = $new if defined $new and length $new;
     }
 
     my $uniq = $self->es_unique;
@@ -518,7 +519,7 @@ sub _delete_unique_keys {
             = $doc->has_changed($key)
             ? $doc->old_value($key)
             : $doc->$key;
-        $old{$key} = $old if defined $old and length $old;
+        $old{ $uniques->{$key} } = $old if defined $old and length $old;
     }
     my $uniq = $self->es_unique;
     return {
@@ -611,7 +612,7 @@ Elastic::Model::Role::Model - The role applied to your Model
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
